[jboss-cvs] JBossAS SVN: r84273 - branches/Branch_5_0/testsuite/src/main/org/jboss/test/compatibility/test.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Mon Feb 16 13:23:16 EST 2009


Author: dimitris at jboss.org
Date: 2009-02-16 13:23:16 -0500 (Mon, 16 Feb 2009)
New Revision: 84273

Modified:
   branches/Branch_5_0/testsuite/src/main/org/jboss/test/compatibility/test/SerialVersionUIDUnitTestCase.java
Log:
exclude classes from serialVersionUID tests - don't enable legacy mode

Modified: branches/Branch_5_0/testsuite/src/main/org/jboss/test/compatibility/test/SerialVersionUIDUnitTestCase.java
===================================================================
--- branches/Branch_5_0/testsuite/src/main/org/jboss/test/compatibility/test/SerialVersionUIDUnitTestCase.java	2009-02-16 18:14:46 UTC (rev 84272)
+++ branches/Branch_5_0/testsuite/src/main/org/jboss/test/compatibility/test/SerialVersionUIDUnitTestCase.java	2009-02-16 18:23:16 UTC (rev 84273)
@@ -59,21 +59,34 @@
    {
       // The packages in jboss-4.2.3 with known serialization issues
       String[] badPackages = {
-	// Ignore org.apache.* issues
-         "org.apache",
-	// Ignore jgroups issues
-         "org.jgroups",
-	//JBAS-5872 - serialVersionUID mismatches from 4.2.3.GA to be resolved
-	"org.jboss.aspects.versioned.StateManager",
-	"org.jboss.cache.CacheException",
-	"org.jboss.cache.Fqn",
-	"org.jboss.cache.Modification",
-	"org.jboss.cache.ReplicationException",
-	"org.jboss.logging.XLevel",
-	"org.jboss.mx.util.InstanceOfQueryExp",
-	"org.jboss.virtual.plugins.context.jar.NestedJarFromStream",
-	// Exclude due to mismatch when running with JDK 6
-	"javax.xml.ws.soap.SOAPFaultException"
+      "com.arjuna.ats.internal.jbossatx.jta.PropagationContextManager",
+	  // Ignore org.apache.* issues
+      "org.apache",
+      // Ignore hibernate issues
+      "org.hibernate",
+	  // Ignore jgroups issues
+      "org.jgroups",
+	  //JBAS-5872 - serialVersionUID mismatches from 4.2.3.GA to be resolved
+	  "org.jboss.aspects.versioned.StateManager",
+	  "org.jboss.cache.CacheException",
+	  "org.jboss.cache.Fqn",
+	  "org.jboss.cache.Modification",
+	  "org.jboss.cache.ReplicationException",
+	  "org.jboss.logging.XLevel",
+	  "org.jboss.mx.util.InstanceOfQueryExp",
+	  "org.jboss.virtual.plugins.context.jar.NestedJarFromStream",
+	  "org.jboss.console",
+	  "org.jboss.ejb3.stateful.StatefulBeanContextReference",
+	  "org.jboss.iiop",
+	  "org.jboss.security.NestableGroup",
+	  "org.jboss.security.NestablePrincipal",
+	  "org.jboss.tm.iiop._TransactionServiceStub",
+	  "org.jboss.wsf",
+	  // Exclude due to mismatch when running with JDK 6
+	  "javax.xml.ws.soap.SOAPFaultException",
+	  // other
+	  "javax.xml.registry.JAXRException",
+	  "javax.xml.registry.RegistryException"
       };
 
       System.out.println("+++ test423Compatibility");
@@ -85,7 +98,6 @@
       Map classInfoMap = (Map) ois.readObject();
       System.out.println("4.2.3 serial classes count: "+classInfoMap.size());
 
-      System.setProperty("org.jboss.j2ee.LegacySerialization", "true");
       Map currentClassInfoMap = calcClassInfoMap();
       int mismatchCount = compare(classInfoMap, currentClassInfoMap, "423", badPackages);
       currentClassInfoMap.clear();




More information about the jboss-cvs-commits mailing list